Crate sf32lb52_pac

Crate sf32lb52_pac 

Peripheral access API for SF32LB52X microcontrollers (generated using svd2rust v0.35.0 ( ))

You can find an overview of the generated API here.

API features to be included in the next svd2rust release can be generated by cloning the svd2rust repository, checking out the above commit, and running cargo doc --open.

Re-exports

pub use self::Interrupt as interrupt;
pub use self::mpi1 as mpi2;
pub use self::usart1 as usart2;
pub use self::usart1 as usart3;
pub use self::spi1 as spi2;
pub use self::i2c1 as i2c2;
pub use self::i2c1 as i2c3;
pub use self::i2c1 as i2c4;
pub use self::gptim1 as gptim2;
pub use self::btim1 as btim2;
pub use self::lptim1 as lptim2;
pub use self::dmac1 as dmac2;
pub use self::usart1 as usart4;
pub use self::usart1 as usart5;
pub use self::btim1 as btim3;
pub use self::btim1 as btim4;
pub use self::wdt1 as wdt2;
pub use self::ptc1 as ptc2;
pub use self::lptim1 as lptim3;
pub use self::crc1 as crc2;

Modules

aes
AES
atim1
Advanced Timer
audcodec
AUDCODEC
audprc
Audio Process Controller
btim1
Basic Timer
crc1
Cyclic Redundancy Check
dmac1
DMAC1
efusec
efuse control
epic
EPIC
extdma
EXTDMA
ezip1
EZIP1
generic
Common register and bit access and modify traits
gpadc
GPADC
gptim1
General Purpose Timer
hpsys_aon
HPSYS_AON
hpsys_cfg
HPSYS_CFG
hpsys_gpio
HPSYS_GPIO
hpsys_pinmux
HPSYS_PINMUX
hpsys_rcc
HPSYS_RCC
i2c1
I2C
i2s1
Inter IC Sound
iwdt
IWatchdog
lcdc1
LCD Controller
lpsys_aon
LPSYS_AON
lpsys_cfg
LPSYS_CFG
lpsys_pinmux
LPSYS_PINMUX
lpsys_rcc
LPSYS_RCC
lptim1
Low Power Timer
mpi1
Memory Peripheral Interface
pdm1
Pulse Density Modulation
pmuc
PMUC
ptc1
PTC1
sdmmc1
SDMMC1
spi1
SPI
trng
True Random Number Generator
tsen
TSEN
usart1
USART
wdt1
Watchdog 1

Structs

Aes
AES
Atim1
Advanced Timer
Audcodec
AUDCODEC
Audprc
Audio Process Controller
Btim1
Basic Timer
Btim2
Basic Timer
Btim3
Basic Timer
Btim4
Basic Timer
CBP
Cache and branch predictor maintenance operations
CPUID
CPUID
CorePeripherals
Core peripherals
Crc1
Cyclic Redundancy Check
Crc2
Cyclic Redundancy Check
DCB
Debug Control Block
DWT
Data Watchpoint and Trace unit
Dmac1
DMAC1
Dmac2
DMAC2
Efusec
efuse control
Epic
EPIC
Extdma
EXTDMA
Ezip1
EZIP1
FPB
Flash Patch and Breakpoint unit
FPU
Floating Point Unit
Gpadc
GPADC
Gptim1
General Purpose Timer
Gptim2
General Purpose Timer
HpsysAon
HPSYS_AON
HpsysCfg
HPSYS_CFG
HpsysGpio
HPSYS_GPIO
HpsysPinmux
HPSYS_PINMUX
HpsysRcc
HPSYS_RCC
I2c1
I2C
I2c2
I2C
I2c3
I2C
I2c4
I2C
I2s1
Inter IC Sound
ITM
Instrumentation Trace Macrocell
Iwdt
IWatchdog
Lcdc1
LCD Controller
LpsysAon
LPSYS_AON
LpsysCfg
LPSYS_CFG
LpsysPinmux
LPSYS_PINMUX
LpsysRcc
LPSYS_RCC
Lptim1
Low Power Timer
Lptim2
Low Power Timer
Lptim3
Low Power Timer
MPU
Memory Protection Unit
Mpi1
Memory Peripheral Interface
Mpi2
Memory Peripheral Interface
NVIC
Nested Vector Interrupt Controller
Pdm1
Pulse Density Modulation
Peripherals
All the peripherals.
Pmuc
PMUC
Ptc1
PTC1
Ptc2
PTC2
SCB
System Control Block
SYST
SysTick: System Timer
Sdmmc1
SDMMC1
Spi1
SPI
Spi2
SPI
TPIU
Trace Port Interface Unit
Trng
True Random Number Generator
Tsen
TSEN
Usart1
USART
Usart2
USART
Usart3
USART
Usart4
USART
Usart5
USART
Wdt1
Watchdog 1
Wdt2
Watchdog 2

Enums

Interrupt
Enumeration of all the interrupts.

Constants

NVIC_PRIO_BITS
Number available in the NVIC for configuring priority

Attribute Macros

interrupt